summaryrefslogtreecommitdiffstats
path: root/src/Mobs/Behaviors/BehaviorBrave.h
diff options
context:
space:
mode:
authorLogicParrot <LogicParrot@users.noreply.github.com>2017-09-08 16:52:30 +0200
committerLogicParrot <LogicParrot@users.noreply.github.com>2017-09-08 16:52:30 +0200
commit40503ab8912c21c8f7913b190fcf835dd8ad18d1 (patch)
tree5ec63036a2c852704a92e8ce1b3f111a13ed8d0a /src/Mobs/Behaviors/BehaviorBrave.h
parentmerge (diff)
downloadcuberite-40503ab8912c21c8f7913b190fcf835dd8ad18d1.tar
cuberite-40503ab8912c21c8f7913b190fcf835dd8ad18d1.tar.gz
cuberite-40503ab8912c21c8f7913b190fcf835dd8ad18d1.tar.bz2
cuberite-40503ab8912c21c8f7913b190fcf835dd8ad18d1.tar.lz
cuberite-40503ab8912c21c8f7913b190fcf835dd8ad18d1.tar.xz
cuberite-40503ab8912c21c8f7913b190fcf835dd8ad18d1.tar.zst
cuberite-40503ab8912c21c8f7913b190fcf835dd8ad18d1.zip
Diffstat (limited to 'src/Mobs/Behaviors/BehaviorBrave.h')
-rw-r--r--src/Mobs/Behaviors/BehaviorBrave.h13
1 files changed, 11 insertions, 2 deletions
diff --git a/src/Mobs/Behaviors/BehaviorBrave.h b/src/Mobs/Behaviors/BehaviorBrave.h
index 0a59f90b8..1562c0089 100644
--- a/src/Mobs/Behaviors/BehaviorBrave.h
+++ b/src/Mobs/Behaviors/BehaviorBrave.h
@@ -2,8 +2,17 @@
#include "Behavior.h"
-/** Makes the mob fight back any other mob that damages it. Mob should have BehaviorAttacker to work.
-This behavior does not make sense in combination with BehaviorCoward. */
+/** Makes the mob fight back any other mob that damages it. Unlike cBehaviorAggressive, it will
+not attack unless provoked.
+
+Connections to other behaviors:
+ - The mob should also have a cBehaviorAttacker, otherwise this behavior will not work.
+ - This behavior does not make sense in combination with BehaviorCoward or cBehaviorAggressive.
+
+Special connections:
+ - Relies on cMonster::GetAttackerBehavior to obtain the attacker behavior and alter its target.
+
+*/
class cBehaviorBrave : cBehavior
{
public: